import { curry } from 'ramda'
import cursorSelect from './cursorSelect'

/**
 * A wrapper for cursor.select(path).get() that uses JSON Paths.
 *
 * ** Sig: DataCursor -> jsonPath -> Any **
 *
 * @function
 * @implements curry
 * @memberof lib
 * @param {Object} DataCursor - The base from which the select path will be made
 * @param {string} jsonPath - The JSON path that will traverse the tree
 * @return {any} - The value at the given path
 * @example
 *
 * let cursor = new Baobab({
 *   foo: {
 *     bar: 23
 *   }
 * })
 * let jsonPath = '/foo/bar/'
 *
 * lib.cursorGet(cursor, jsonPath) // 23
 * lib.cursorGet(cursor)(jsonPath) // 23 - curried
 *
 */
const cursorGet = curry((cursor, jsonPath) =>
    cursorSelect(cursor, jsonPath).get())

export default cursorGet
