import { curry } from 'ramda'
import listPath from './listPath'

/**
 * A wrapper for cursor.select(path) to get a nested cursor.
 *
 * ** Sig: DataCursor -> jsonPath -> DataCursor **
 *
 * @function
 * @implements curry
 * @memberof lib
 * @param {Object} DataCursor - The base from which the select path will be made
 * @param {string} jsonPath - The JSON path that will traverse the tree
 * @return {Object} - The nested cursor found at the given path
 * @example
 *
 * let cursor = new Baobab({
 *   foo: {
 *     bar: 23
 *   }
 * })
 * let jsonPath = '/foo/bar/'
 *
 * let fooBarCursor = lib.cursorSelect(cursor, jsonPath)
 * fooBarCursor.get() // 23
 *
 */
const cursorSelect = curry((cursor, jsonPath) =>
    cursor.select(listPath(jsonPath)))

export default cursorSelect
